@@ -113,9 +113,11 @@ export class MapMarker extends Shumate.Marker {
     }
 
     get bubble() {
-        if (this._bubble === undefined && this._hasBubble())
+        if (this._bubble === undefined && this._hasBubble()) {
             this._bubble = new MapBubble({ place: this._place,
-                                           mapView: this._mapView });
+                                            mapView: this._mapView });
+            this._bubble.set_parent(this._mapView);
+        }
 
         return this._bubble;
     }
@@ -231,8 +233,6 @@ export class MapMarker extends Shumate.Marker {
 
     showBubble() {
         if (this.bubble && !this.bubble.visible && this._isInsideView() && !Application.application.adaptive_mode) {
-            if (this._bubble.get_parent() === null)
-                this._bubble.set_parent(this._mapView);
             this._initBubbleSignals();
             this.bubble.popup();
             this._positionBubble(this.bubble);
@@ -288,7 +288,7 @@ export class MapMarker extends Shumate.Marker {
     }
 
     _onAdaptiveModeChanged() {
-        if (!Application.application.adaptive_mode) {
+        if (!Application.application.adaptive_mode && this.get_mapped()) {
             this.showBubble();
         } else {
             this.hideBubble();
