@@ -309,9 +309,9 @@ export const DEFS = {
                 ],
                 bicycle_rental: ["cycling-symbolic", "transport", 16],
                 biergarten: ["pub-symbolic", "food"],
-                bus_station: ["route-transit-bus-symbolic", "transport"],
+                bus_station: ["bus-symbolic", "transport"],
                 cafe: ["cafe-symbolic", "food"],
-                car_rental: ["route-car-symbolic", "transport"],
+                car_rental: ["driving-symbolic", "transport"],
                 charging_station: ["electric-car-symbolic", "transport"],
                 cinema: ["video-camera-symbolic", "generic"],
                 clinic: ["hospital-sign-symbolic", "healthAndSafety"],
@@ -321,11 +321,7 @@ export const DEFS = {
                 doctors: ["hospital-sign-symbolic", "healthAndSafety"],
                 drinking_water: ["drinking-fountain-symbolic", "micro", 16],
                 fast_food: ["fast-food-symbolic", "food"],
-                ferry_terminal: [
-                    "route-transit-ferry-symbolic",
-                    "transport",
-                    13,
-                ],
+                ferry_terminal: ["ferry-symbolic", "transport", 13],
                 firepit: ["barbecue-symbolic", "micro", 16],
                 fire_station: ["firefighter-symbolic", "healthAndSafety", 15],
                 food_court: ["restaurant-symbolic", "food"],
@@ -347,6 +343,7 @@ export const DEFS = {
                 recycling: ["recycling-bin-symbolic", "micro", 16],
                 restaurant: ["restaurant-symbolic", "food"],
                 school: ["school-symbolic", "education"],
+                taxi: ["taxi-symbolic", "transportation", 16],
                 theatre: ["theater-symbolic", "generic"],
                 toilets: ["toilets-symbolic", "micro", 16],
                 university: ["school-symbolic", "education", 13],
@@ -355,22 +352,23 @@ export const DEFS = {
             },
             barrier: {
                 bollard: false,
+                cycle_barrier: ["gate-symbolic", "traffix", 17, 0.75],
                 gate: ["gate-symbolic", "traffic", 17, 0.75],
                 lift_gate: ["gate-symbolic", "traffic", 17, 0.75],
             },
             building: {
-                railway_station: ["route-transit-train", "transport", 16],
+                railway_station: ["train-symbolic", "transport", 16],
                 _: ["building-symbolic", "generic", 16],
             },
             highway: {
-                bus_stop: ["route-transit-bus-symbolic", "transport", 16],
-                cycleway: ["route-bike-symbolic", "transport", 16],
-                footway: ["route-pedestrian-symbolic", "transport", 16],
-                pedestrian: ["route-pedestrian-symbolic", "transport", 16],
-                platform: ["route-transit-bus-symbolic", "transport", 16],
+                bus_stop: ["bus-symbolic", "transport", 16],
+                cycleway: ["cycling-symbolic", "transport", 16],
+                footway: ["walking-symbolic", "transport", 16],
+                pedestrian: ["walking-symbolic", "transport", 16],
+                platform: ["bus-symbolic", "transport", 16],
                 steps: ["steps-symbolic", "transport", 16],
-                path: ["route-pedestrian-symbolic", "transport", 16],
-                _: ["route-car-symbolic", "transport", 16],
+                path: ["walking-symbolic", "transport", 16],
+                _: ["driving-symbolic", "transport", 16],
             },
             historic: {
                 monument: ["museum-symbolic", "public"],
@@ -394,6 +392,7 @@ export const DEFS = {
                 nature_reserve: ["tree-symbolic", "parks", 10],
                 park: ["tree-symbolic", "parks", 10],
                 pitch: ["@sport", "parks", 16],
+                playground: ["playground3-symbolic", "parks", 16],
                 sports_centre: ["@sport", "parks", 13],
                 stadium: ["@sport", "parks", 14],
                 swimming_pool: false,
@@ -419,19 +418,19 @@ export const DEFS = {
                 quarter: ["town-symbolic"],
                 province: ["flag-outline-thick-symbolic"],
                 region: ["flag-outline-thick-symbolic"],
-                square: ["route-pedestrian-symbolic"],
+                square: ["walking-symbolic"],
                 state: ["flag-outline-thick-symbolic"],
                 suburb: ["town-symbolic"],
                 town: ["town-symbolic"],
                 village: ["town-symbolic"],
             },
             railway: {
-                halt: ["route-transit-train-symbolic", "transport", 16],
-                station: ["route-transit-train-symbolic", "transport", 16],
-                stop: ["route-transit-train-symbolic", "transport", 16],
+                halt: ["train-symbolic", "transport", 16],
+                station: ["train-symbolic", "transport", 16],
+                stop: ["train-symbolic", "transport", 16],
                 subway_entrance: ["exit-symbolic", "transport", 16],
                 train_station_entrance: ["exit-symbolic", "transport", 16],
-                tram_stop: ["route-transit-tram-symbolic", "transport", 16],
+                tram_stop: ["tram-symbolic", "transport", 16],
             },
             shop: {
                 alcohol: ["drinks-symbolic", "generic"],
@@ -508,7 +507,7 @@ export const DEFS = {
             },
         },
         {
-            classes: ["service"],
+            classes: ["service", "track"],
             color: {
                 dark: "#2a2924",
                 light: "#c8c7b4",
